#!/bin/bash
#
# Dump eines SVN Repositories
#
# Ohne Parameter: Backup aller repositories aus $PARREPRO
# Parameter $1..n: SVN Repository Name(n)
#
# Beispiel: sh svnbackup.sh
# Beispiel: sh svnbackup.sh projekt1 projekt2 projekt3
#
# Stand 04.01.2020/Mm
#
# Parameter Reprository:
PARREPRO="/volume1/svn"
# Parameter Backup Verzeichnis
# Unter diesem Verzeichnis müssen die Ordner "backup" und "dump" angelegt sein
PARBAKHUP="/volume1/install/_Backup/svndump"
# Überprüfen Verzeichnisstruktur für Backup
if [ ! -e $PARBAKHUP/backup ]
then
  echo "Sicherungsverzeichnis $PARBAKHUP/backup existiert nicht!"
  exit 1
fi
if [ ! -e $PARBAKHUP/dump ]
then
  echo "Sicherungsverzeichnis $PARBAKHUP/dump existiert nicht!"
  exit 1
fi
# Überprüfen der Parametrierung:
REPROS="$@"
if [ "$REPROS" == "" ]
then
  REPROS=`find $PARREPRO/ -maxdepth 1 -type d -not -path '*/\@*' -not -path '*/' | sed 's/^\.\///g' | sort`
fi
# Schleife über alle zu sichernde repros
for EACHREPRO in $REPROS
do
  REPRO=`basename $EACHREPRO`
  DATE=`date +%Y%m%d_%H%M%S`
  if [ ! -e "$PARREPRO/$REPRO" ]
  then
    echo "${DATE} Repository $REPRO existiert nicht!" >> $PARBAKHUP/Log.txt
    continue
  fi
  # Lesen der aktuellen SVN HEAD Version von $REPRO Repository
  HEAD=`/volume1/@appstore/SVN/bin/svnlook youngest $PARREPRO/$REPRO`
  if [ -e $PARBAKHUP/dump/$REPRO.svnhead ]
  then
    HEADLAST=`cat $PARBAKHUP/dump/$REPRO.svnhead`
  else
    HEADLAST="0"
  fi
  # Überprüfe ob ein Backup durchgeführt werden muss:
  if [ "$HEAD" == "$HEADLAST" ]
  then
    echo "${DATE} Backup von $REPRO:$HEAD nicht nötig. SVN Version letztes Backup $HEADLAST" >> $PARBAKHUP/Log.txt
    continue
  fi
  # Starte Backup, Logdatei
  echo "backup von repository $REPRO am $DATE" > $PARBAKHUP/dump/$REPRO-${DATE}.svnlog
  echo "HEAD SVN Version letztes Backup $HEADLAST >> aktuell: $HEAD" >> $PARBAKHUP/dump/$REPRO-${DATE}.svnlog
  # Dump aus SVN in GZ Datei
  rm -r $PARBAKHUP/dump/$REPRO*.svndump.gz 2> /dev/null
  rm -r $PARBAKHUP/dump/$REPRO*.svnlog 2> /dev/null
  echo "${DATE} Backup Start: $REPRO:$HEAD" >> $PARBAKHUP/Log.txt
  /volume1/@appstore/SVN/bin/svnadmin dump $PARREPRO/$REPRO 2> $PARBAKHUP/dump/$REPRO-$HEAD-${DATE}.svnlog | gzip -c -5 > $PARBAKHUP/dump/$REPRO-$HEAD-${DATE}.svndump.gz
  # Überprüfe Backup Datei, ob was drin steht (Dateigröße > 1000 Byte)
  actualsize=$(wc -c <"$PARBAKHUP/dump/$REPRO-${DATE}.svndump.gz")
  if [ $actualsize -le 1000 ]
  then
    echo "${DATE} Backup von $REPRO:$HEAD fehlerhaft!" >> $PARBAKHUP/Log.txt
    continue
  fi
  rm -r $PARBAKHUP/backup/$REPRO-*.svndump.gz 2> /dev/null
  rm -r $PARBAKHUP/backup/$REPRO-*.svnlog 2> /dev/null
  mv -f $PARBAKHUP/dump/$REPRO-*.svndump.gz $PARBAKHUP/backup/
  mv -f $PARBAKHUP/dump/$REPRO-*.svnlog $PARBAKHUP/backup/
  echo "$HEAD" > $PARBAKHUP/dump/$REPRO.svnhead
  echo "${DATE} Backup fertig: $REPRO:$HEAD" >> $PARBAKHUP/Log.txt
done
exit 0
